# -*- coding: utf-8 -*-
# pylint: disable=unused-import
""":class:`~pcapkit.protocols.transport.tcp.TCP` Vendor Crawlers
===================================================================

.. module:: pcapkit.vendor.tcp

This module contains all vendor crawlers of
:class:`~pcapkit.protocols.transport.tcp.TCP` implementations. Available
enumerations include:

.. list-table::

   * - :class:`TCP_Checksum <pcapkit.vendor.tcp.checksum.Checksum>`
     - TCP Checksum [*]_
   * - :class:`TCP_MPTCPOption <pcapkit.vendor.tcp.mp_tcp_option.MPTCPOption>`
     - Multipath TCP options [*]_
   * - :class:`TCP_Option <pcapkit.vendor.tcp.option.Option>`
     - TCP Option Kind Numbers

.. [*] https://www.iana.org/assignments/tcp-parameters/tcp-parameters.xhtml#tcp-parameters-2
.. [*] https://www.iana.org/assignments/tcp-parameters/tcp-parameters.xhtml#tcp-parameters-1

"""

from pcapkit.vendor.tcp.checksum import Checksum as TCP_Checksum
from pcapkit.vendor.tcp.mp_tcp_option import MPTCPOption as TCP_MPTCPOption
from pcapkit.vendor.tcp.option import Option as TCP_Option

__all__ = ['TCP_Checksum', 'TCP_Option', 'TCP_MPTCPOption']
